DEFAULT_CONFIG = {
	display = {
		width = 1280,
		height = 720
	},
	game = {
		highScore = 0
	}
}

function love.load()

	--Loading Assets
	ini = require "src.class.ini"
	theme = require "src.theme.theme"
	text = require "src.class.text"
	player = require "src.entity.player"
	platform = require "src.entity.platform"
	game = require "src.state.game"

	IDENTITY = "Flappy juice"
	love.filesystem.setIdentity(IDENTITY)
	CONFIG = DEFAULT_CONFIG

	--Creating/loading config file
	if love.filesystem.exists("config.ini") then
		CONFIG = ini.load("config.ini")
	else
		ini.save("config.ini", CONFIG)
	end

	if not love.filesystem.exists("screenshots") then
		love.filesystem.createDirectory("screenshots")
	end

	love.window.setMode(CONFIG.display.width, CONFIG.display.height, {resizable = true})
	love.window.setTitle("Flappy Juice")

	screen = {
		width = love.graphics.getWidth(),
		height = love.graphics.getHeight()
	}

	--Font
	FONT = {
		small = love.graphics.newFont("src/font/CODE Bold.otf", math.floor(screen.height * 0.06)),
		large = love.graphics.newFont("src/font/CODE Bold.otf", math.floor(screen.height * 0.09)),
	}

	--GLOBAL
	GRAVITY = screen.height * 1.2
	OS = love.system.getOS()
	SMOOTH_FACTOR = 6
	SMOOTH_CUTOFF = 0.1

	--Init
	theme:load()
	theme:apply("default")
	game:load()
end

function love.update(dt)
	game:update(dt)
end

function love.draw()
	game:draw()
end

function love.keypressed(key)
	if key == "escape" then 
		if love.keyboard.isDown("lshift") or love.keyboard.isDown("rshift") then
			love.event.push("quit")
		end 
	elseif key == "f3" then
		screenshot()
	end

	game:keypressed(key)
end

function love.resize(width, height)
	screen.width = width
	screen.height = height

	CONFIG.display.width = width
	CONFIG.display.height = height
	--Font
	FONT = {
		small = love.graphics.newFont("src/font/CODE Bold.otf", math.floor(screen.height * 0.06)),
		large = love.graphics.newFont("src/font/CODE Bold.otf", math.floor(screen.height * 0.09)),
	}

	--GLOBAL
	GRAVITY = screen.height * 1.2

	game:load()
end

function love.mousepressed(x, y, key)
	game:mousepressed(x, y, key)
end

function love.touchpressed(id, x, y, dx, dy, pressure)
	game:touchpressed(id, x, y, dx, dy, pressure)
end

function love.quit()
	ini.save("config.ini", CONFIG)
end

function setAlpha(a)
	local r, g, b, _ = love.graphics.getColor()
	love.graphics.setColor(r, g, b, a)
end

function AABB(x1,y1,w1,h1, x2,y2,w2,h2)
  return x1 < x2+w2 and
         x2 < x1+w1 and
         y1 < y2+h2 and
         y2 < y1+h1
end

function screenshot()
	local screenshot = love.graphics.newScreenshot()
    screenshot:encode('png', "screenshots/"..os.time() .. '.png')
end