local text = {}
local tm = {__index = text}

function text.new(text, x, y, align, font, color, hideDirection)
	hideDirection = hideDirection or "bottom"
	local t = {
		text = text,
		x = x,
		y = y,
		showY = y,
		dx = x,
		dy = y,
		align = align,
		font = font,
		color = color,
		hideDirection = hideDirection
	}
	t.shadowDistance = math.floor( (t.font:getAscent() - t.font:getDescent()) * 0.1 )
	return setmetatable(t, tm)
end

function text:update(dt)
	self.dx = self.dx + (self.x - self.dx) * (SMOOTH_FACTOR * dt)
	self.dy = self.dy + (self.y - self.dy) * (SMOOTH_FACTOR * dt)
end

function text:hide(instant)
	instant = instant or false
	if self.hideDirection == "bottom" then
		self.y = screen.height * 1.1
	elseif self.hideDirection == "top" then
		self.y = -(screen.height * 0.1)
	end
	if instant then
		self.dy = self.y
	end
end

function text:show(instant)
	instant = instant or false
	self.y = self.showY
	if instant then
		self.dy = self.y
	end
end

function text:setText(t)
	self.text = t
end

function text:draw()
	love.graphics.setFont(self.font)
	love.graphics.setColor(0, 0, 0, 64)
	love.graphics.printf(self.text, self.dx, self.dy + self.shadowDistance, screen.width, self.align)

	love.graphics.setColor(self.color)
	love.graphics.printf(self.text, self.dx, self.dy, screen.width, self.align)
end

return text